@@ -1,5 +1,8 @@
+from __future__ import unicode_literals, absolute_import
+
 from django.contrib import admin
-from console.models import *
+
+from .models import *
 
 
 class ContainerMetricAdmin(admin.ModelAdmin):
