@@ -5,9 +5,7 @@ function filter_list(e){
     if (last_filters[filter] == undefined || last_filters[filter] != e.val){
         $('.table_row.hidden').removeClass('hidden');
     }
-    console.log(e.val);
     if (e.val == ''){
-        console.log('bella');
         last_filters[filter] = undefined;
     }
     else{
@@ -17,7 +15,6 @@ function filter_list(e){
     for (k in last_filters){
         if (last_filters[k] != undefined){
             query_string += '[data-'+k+'*="'+last_filters[k]+'"]';
-            console.log(query_string);
         }
     }
     if (query_string != ''){
