@@ -1,14 +1,15 @@
 from __future__ import unicode_literals, absolute_import
-import json
 from datetime import datetime
+import json
 
+from django.conf import settings
+from django.contrib import messages
 from django.template import RequestContext
 from django.shortcuts import render_to_response
-from django.contrib import messages
-from django.http import HttpResponseRedirect, HttpResponse
-from django.conf import settings
+from django.http import HttpResponseRedirect, HttpResponse,\
+    HttpResponseForbidden
 
-from uwsgiit.api import UwsgiItClient as UC
+from .utils import ConsoleClient as CC
 
 from .decorators import login_required
 from .forms import LoginForm, MeForm, SSHForm, ContainerForm, TagForm,\
@@ -27,11 +28,11 @@ def main_render(request, template, v_dict={}):
     api_url = request.session.get('api_url', False)
 
     if username and password and api_url:
-        client = UC(username, password, api_url)
+        client = CC(username, password, api_url)
 
         v_dict['containers'] = sorted(
             client.containers().json(), key=lambda k: k['name'])
-        last_alarm = client.alarms(range=1).json()
+        last_alarm = client.alarms({'range': 1}).json()
         if last_alarm:
             v_dict['last_alarm_id'] = last_alarm[0]['id']
 
@@ -56,7 +57,7 @@ def home(request):
     password = request.session.get('password', None)
     api_url = request.session.get('api_url', settings.DEFAULT_API_URL)
 
-    client = UC(username, password, api_url)
+    client = CC(username, password, api_url)
 
     news = client.news().json()
     for n in news:
@@ -70,7 +71,9 @@ def home(request):
         if 'del-alarm' in request.GET:
             client.delete_alarm(request.GET['del-alarm'])
 
-        v_dict['alarms'] = client.alarms(range='10').json()
+        v_dict['alarms'] = client.alarms({'range': 10}).json()
+        if 'error' in v_dict['alarms']:
+            return logout(request)
 
         for a in v_dict['alarms']:
             a['unix'] = datetime.fromtimestamp(a['unix'])
@@ -80,11 +83,14 @@ def home(request):
 
 @login_required
 def me_page(request):
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
 
     me = client.me().json()
+    if 'error' in me:
+        return logout(request)
+
     v_dict = {'me': me}
     me_form = MeForm(initial={
         'company': me['company'],
@@ -115,24 +121,13 @@ def me_page(request):
 @login_required
 def containers(request, id):
     res = {}
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
     if id:
         container = client.container(id).json()
-
-        container_copy = container.copy()
-        del container_copy['ssh_keys']
-        del container_copy['distro']
-        del container_copy['distro_name']
-        del container_copy['tags']
-        del container_copy['note']
-        del container_copy['quota_threshold']
-        del container_copy['nofollow']
-        del container_copy['linked_to']
-        del container_copy['jid']
-        del container_copy['jid_destinations']
-        del container_copy['name']
+        if 'error' in container:
+            return logout(request)
 
         # Get last quota metric
         quota_metrics = client.container_metric(id, 'quota', None).json()
@@ -143,15 +138,12 @@ def containers(request, id):
         else:
             used_quota = 0
 
-        container_copy['storage'] = str(used_quota) + ' / ' + str(container_copy['storage']) + ' MB'
-        container_copy['memory'] = str(container_copy['memory']) + 'MB'
-        res['container_copy'] = container_copy
         res['container'] = container
 
         distros_list = sorted(client.distros().json(), key=lambda distro: distro['id'], reverse=True)
         distros_list = [(x['id'], x['name']) for x in distros_list]
 
-        tag_list = [(x['name'], x['name']) for x in client.list_tags().json()]
+        tag_list = client.get_tag_list()
 
         containers_actual_linked_to = [x for x in client.containers().json() if x['uid'] != int(id)]
 
@@ -162,20 +154,21 @@ def containers(request, id):
             tag_choices=tag_list,
             linked_to_choices=linked_to,
             distro_choices=distros_list,
-            initial={
-                'name': container['name'],
-                'quota_threshold': container['quota_threshold'],
-                'nofollow': container['nofollow'],
-                'distro': '{}'.format(container['distro']),
-                'note': container['note'],
-                'jid': container['jid'],
-                'jid_destinations': container['jid_destinations']
-            }
+            initial=container
         )
         sshform = SSHForm()
         calendar = CalendarForm()
         newloopboxform = NewLoopboxForm()
 
+        container_copy = {k: container[k] for k in container if k not in containerform.fields}
+        del container_copy['ssh_keys']
+        del container_copy['distro_name']
+
+        container_copy['storage'] = str(used_quota) + ' / ' + str(container_copy['storage']) + ' MB'
+        container_copy['memory'] = str(container_copy['memory']) + 'MB'
+
+        res['container_copy'] = container_copy
+
         active_panel = None
         if request.POST:
             if 'distro' in request.POST:
@@ -196,12 +189,16 @@ def containers(request, id):
                     }
 
                     optional_values = (
-                        'name', 'jid', 'jid_destinations', 'jid_secret')
-
+                        'name', 'jid', 'jid_destinations', 'jid_secret',
+                        'alarm_freq', 'pushover_user', 'pushover_token',
+                        'pushover_sound'
+                    )
                     for ov in optional_values:
                         if ov in cd:
                             container_updates[ov] = cd[ov]
-                    client.update_container(id, container_updates)
+                    if 'reboot' in cd and cd['reboot']:
+                        container_updates['reboot'] = True
+                    # client.update_container(id, container_updates)
 
                     list_linked_to = [x['uid'] for x in containers_actual_linked_to]
 
@@ -265,7 +262,7 @@ def containers(request, id):
                 active_panel = 'alarms'
                 client.delete_alarm(request.GET['del-alarm'])
 
-        res['alarms'] = client.alarms(container=id).json()
+        res['alarms'] = client.alarms({'container': id}).json()
 
         alarms_used_keys = ('a_color', 'a_container', 'a_class', 'a_level', 'a_vassal', 'a_filename', 'a_func', 'a_line')
         for k in alarms_used_keys:
@@ -315,7 +312,7 @@ def containers(request, id):
 @login_required
 def domains(request):
     res = {}
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
 
@@ -323,25 +320,23 @@ def domains(request):
     calendar = CalendarForm()
 
     all_tags = client.list_tags().json()
+    if 'error' in all_tags:
+        return logout(request)
 
-    tags_list = [('', '')] + [(x['name'], x['name']) for x in all_tags]
+    tags_list = client.get_tag_list()
 
     if request.POST:
         if 'name' in request.POST:
             new_domain = NewDomainForm(request.POST)
             if new_domain.is_valid():
                 name = new_domain.cleaned_data['name']
-                client.add_domain(name)
-                new_domain = NewDomainForm()
-        else:
-            domain_form = DomainForm(data=request.POST, tag_choices=tags_list)
-            if domain_form.is_valid():
-                cd = domain_form.cleaned_data
-                did = cd['did']
-                tags_post = []
-                if '{}-tags'.format(did) in request.POST:
-                    tags_post = request.POST.getlist('{}-tags'.format(did))
-                client.update_domain(did, {'tags': tags_post})
+                r = client.add_domain(name)
+                if r.uerror:
+                    new_domain.add_error(None, 'Error: {}'.format(r.json()['error']))
+                else:
+                    messages.success(
+                        request, 'domain {} successfully added'.format(name))
+                    new_domain = NewDomainForm()
     if 'del' in request.GET:
         name = request.GET['del']
         client.delete_domain(name)
@@ -360,10 +355,11 @@ def domains(request):
     used_tags = []
 
     for d in doms:
-        form = DomainForm(initial={'did': d['id'], 'tags': d['tags']}, prefix=d['id'], tag_choices=tags_list)
+        form = DomainForm(initial={'tags': d['tags']}, prefix=d['id'], tag_choices=tags_list)
         domains_list.append((d, form))
         used_tags.extend([tag for tag in d['tags'] if tag not in used_tags])
 
+    res['uuid'] = client.me().json()['uuid']
     res['domains'] = domains_list
     res['new_domain'] = new_domain
     res['calendar'] = calendar
@@ -376,14 +372,19 @@ def domains(request):
 def domain(request, id):
     calendar = CalendarForm()
     res = {}
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
 
-    tags_list = [('', '')] + [(x['name'], x['name']) for x in client.list_tags().json()]
+    all_tags = client.list_tags().json()
+    if 'error' in all_tags:
+        return logout(request)
+
+    tags_list = client.get_tag_list()
 
     if request.POST:
-        if 'did' in request.POST:
+        if 'tags' in request.POST or\
+            'note' in request.POST:
             domain_form = DomainForm(data=request.POST, tag_choices=tags_list)
             if domain_form.is_valid():
                 cd = domain_form.cleaned_data
@@ -399,7 +400,7 @@ def domain(request, id):
 
     domain = client.domain(id).json()
     form = DomainForm(tag_choices=tags_list, initial={
-        'did': id, 'tags': domain['tags'], 'note': domain['note']})
+        'tags': domain['tags'], 'note': domain['note']})
 
     del domain['tags']
     del domain['note']
@@ -414,7 +415,7 @@ def domain(request, id):
 def tags(request):
     res = {}
     tagform = TagForm()
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
 
@@ -424,11 +425,16 @@ def tags(request):
             cd = tagform.cleaned_data
             client.create_tag(cd['name'])
             tagform = TagForm()
+
     elif request.GET and 'id' in request.GET:
         id = request.GET['id']
         client.delete_tag(id)
 
     res['tags'] = client.list_tags().json()
+
+    if 'error' in res['tags']:
+        return logout(request)
+
     res['tagform'] = tagform
     return main_render(request, 'console/tags.html', res)
 
@@ -436,32 +442,40 @@ def tags(request):
 @login_required
 def tag(request, tag):
     res = {}
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
 
+    res['tagged_domains'] = client.domains(tags=[tag]).json()
+    if 'error' in res['tagged_domains']:
+        return logout(request)
     res['tag'] = tag
     res['calendar_domains'] = CalendarForm(auto_id='calendar-domains-%s')
     res['calendar_containers'] = CalendarForm(auto_id='calendar-containers-%s')
-    res['tagged_domains'] = client.domains(tags=[tag]).json()
     res['tagged_containers'] = client.containers(tags=[tag]).json()
     return main_render(request, 'console/tag.html', res)
 
 
 @login_required
 def alarms(request):
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
     res = {}
     alarm_form = AlarmForm()
-    alarms = None
+    alarms = client.alarms({'range': 100}).json()
+
+    if 'error' in alarms:
+        return logout(request)
+
     if request.POST:
         if 'action_filter' in request.POST:
             alarm_form = AlarmForm(request.POST)
             if alarm_form.is_valid():
                 cd = alarm_form.cleaned_data
-                r = client.alarms(**cd)
+                cd['class'] = cd['class_']
+                del cd['class_']
+                r = client.alarms(cd)
                 if r.uerror:
                     alarm_form.add_error(None, r.json()['error'])
                     alarms = ()
@@ -471,8 +485,6 @@ def alarms(request):
     elif 'del-alarm' in request.GET:
             client.delete_alarm(request.GET['del-alarm'])
 
-    if alarms is None:
-        alarms = client.alarms(range=100).json()
     for a in alarms:
         a['unix'] = datetime.fromtimestamp(a['unix'])
     res['alarm_form'] = alarm_form
@@ -482,10 +494,46 @@ def alarms(request):
 
 @login_required
 def latest_alarms(request):
-    client = UC(request.session.get('username'),
+    client = CC(request.session.get('username'),
                 request.session.get('password'),
                 request.session.get('api_url'))
 
-    alarms = client.alarms(range=5)
+    alarms = client.alarms({'range': 5})
+    if 'error' in alarms:
+        return logout(request)
 
     return HttpResponse(alarms.content)
+
+
+@login_required
+def alarm_key(request, id):
+    if request.method == 'POST':
+        client = CC(request.session.get('username'),
+                    request.session.get('password'),
+                    request.session.get('api_url'))
+        r = client.create_alarm_key(id)
+        return HttpResponse(r.content)
+    return HttpResponseForbidden()
+
+
+@login_required
+def add_domain_tag(request, id):
+    if request.method == 'POST' and '{}-tags'.format(id) in request.POST:
+        client = CC(request.session.get('username'),
+                    request.session.get('password'),
+                    request.session.get('api_url'))
+        tags_post = request.POST.getlist('{}-tags'.format(id))
+        r = client.update_domain(id, {'tags': tags_post})
+        return HttpResponse(r.content)
+    return HttpResponseForbidden()
+
+
+@login_required
+def reboot_container(request, id):
+    if request.method == 'POST':
+        client = CC(request.session.get('username'),
+                    request.session.get('password'),
+                    request.session.get('api_url'))
+        r = client.reboot_container(id)
+        return HttpResponse(r.content)
+    return HttpResponseForbidden()
